"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const amazon_cognito_identity_js_1 = require("amazon-cognito-identity-js");
const cli_ux_1 = require("cli-ux");
const storage = require("node-persist");
const TokenStorage = {
    get: async (poolData) => {
        return await storage.getItem(`${poolData.UserPoolId}.${poolData.ClientId}`);
    },
    add: async (poolData, tokens) => {
        return await storage.setItem(`${poolData.UserPoolId}.${poolData.ClientId}`, JSON.stringify(tokens));
    }
};
const GetTokenFromInput = async (poolData) => {
    const username = await cli_ux_1.default.prompt("Username");
    const password = await cli_ux_1.default.prompt("Password", { type: "hide" });
    const authenticationData = {
        Username: username,
        Password: password
    };
    const authenticationDetails = new amazon_cognito_identity_js_1.AuthenticationDetails(authenticationData);
    const userPool = new amazon_cognito_identity_js_1.CognitoUserPool(poolData);
    const userData = {
        Username: username,
        Pool: userPool
    };
    const cognitoUser = new amazon_cognito_identity_js_1.CognitoUser(userData);
    return new Promise((resolve, reject) => {
        cognitoUser.authenticateUser(authenticationDetails, {
            onSuccess: function (result) {
                const idToken = result.idToken.jwtToken;
                const refreshToken = result.refreshToken.token;
                const idTokenTTI = +new Date() + 1800000; //now + 1/2 hour
                TokenStorage.add(poolData, {
                    idToken,
                    idTokenTTI,
                    refreshToken,
                    username
                }).then(() => {
                    resolve(idToken);
                });
            },
            onFailure: function (err) {
                reject(err);
            }
        });
    });
};
const RefreshToken = (token) => ({
    token,
    getToken: () => token
});
const GetTokenFromPersistedCredentials = (data, poolData) => new Promise((resolve, reject) => {
    const tokens = JSON.parse(data);
    const now = +new Date();
    const userPool = new amazon_cognito_identity_js_1.CognitoUserPool(poolData);
    const userData = {
        Username: tokens.username,
        Pool: userPool
    };
    const cognitoUser = new amazon_cognito_identity_js_1.CognitoUser(userData);
    if (now > tokens.idTokenTTI) {
        cognitoUser.refreshSession(RefreshToken(tokens.refreshToken), (err, result) => {
            if (err) {
                reject("Error");
            }
            else {
                const idToken = result.idToken.jwtToken;
                const refreshToken = result.refreshToken.token;
                const idTokenTTI = +new Date() + 1800000; //now + 1/2 hour
                TokenStorage.add(poolData, {
                    idToken,
                    idTokenTTI,
                    refreshToken,
                    username: tokens.username
                }).then(() => {
                    resolve(idToken);
                });
            }
        });
    }
    else {
        resolve(tokens.idToken);
    }
});
const getTokenFromCLI = async (data) => {
    const poolData = data;
    storage.init({ dir: data.storage ? data.storage : "/var/tmp" });
    return !data.reset
        ? TokenStorage.get(data)
            .then((data) => GetTokenFromPersistedCredentials(data, poolData))
            .catch(async () => GetTokenFromInput(data))
        : GetTokenFromInput(data);
};
exports.getTokenFromCLI = getTokenFromCLI;
